@@ -7,6 +7,7 @@ import logging
 import inspect
 import argparse
 import traceback
+import importlib
 import unicodecsv
 
 import datetime as dt
@@ -239,12 +240,12 @@ def main(old_scrape_compat=False):
             sys.path.insert(0, newpath)
 
         # get metadata
-        module = __import__(args.module)
+        module = importlib.import_module(args.module)
         metadata = module.metadata
         module_settings = getattr(module, 'settings', {})
         abbrev = metadata['abbreviation']
 
-        # load state settings, then command line settings
+        # load module settings, then command line settings
         settings.update(module_settings)
         settings.update(args)
 
@@ -406,7 +407,7 @@ def main(old_scrape_compat=False):
             _do_reports(abbrev, args)
 
     except ScrapeError as e:
-        print 'Error:', e
+        logging.getLogger('billy').critical('Error: %s', e)
         sys.exit(1)
 
 
