@@ -73,25 +73,25 @@ def _make_csv(abbr, name, fields):
     return filename, f
 
 
-def dump_legislator_csvs(level, abbr):
+def dump_legislator_csvs(abbr):
     leg_fields = ('leg_id', 'full_name', 'first_name', 'middle_name',
                   'last_name', 'suffixes', 'nickname', 'active',
-                  'level', 'country', 'state', 'chamber', 'district', 'party',
+                  settings.LEVEL_FIELD, 'chamber', 'district', 'party',
                    'transparencydata_id', 'photo_url', 'created_at',
                   'updated_at')
     leg_csv_fname, leg_csv = _make_csv(abbr, 'legislators.csv', leg_fields)
 
-    role_fields = ('leg_id', 'type', 'term', 'district', 'chamber', 'level',
-                   'country', 'state', 'party', 'committee_id', 'committee',
+    role_fields = ('leg_id', 'type', 'term', 'district', 'chamber',
+                   settings.LEVEL_FIELD, 'party', 'committee_id', 'committee',
                    'subcommittee', 'start_date', 'end_date')
     role_csv_fname, role_csv = _make_csv(abbr, 'legislator_roles.csv',
                                          role_fields)
 
-    com_fields = ('id', 'level', 'country', 'state', 'chamber', 'committee',
+    com_fields = ('id', settings.LEVEL_FIELD, 'chamber', 'committee',
                   'subcommittee', 'parent_id')
     com_csv_fname, com_csv = _make_csv(abbr, 'committees.csv', com_fields)
 
-    for legislator in db.legislators.find({'level': level, level: abbr}):
+    for legislator in db.legislators.find({settings.LEVEL_FIELD: abbr}):
         leg_csv.writerow(extract_fields(legislator, leg_fields))
 
         # go through roles to create role csv
@@ -104,7 +104,7 @@ def dump_legislator_csvs(level, abbr):
             d.update({'leg_id': legislator['leg_id']})
             role_csv.writerow(d)
 
-    for committee in db.committees.find({'level': level, level: abbr}):
+    for committee in db.committees.find({settings.LEVEL_FIELD: abbr}):
         cdict = extract_fields(committee, com_fields)
         cdict['id'] = committee['_id']
         com_csv.writerow(cdict)
@@ -112,23 +112,23 @@ def dump_legislator_csvs(level, abbr):
     return leg_csv_fname, role_csv_fname, com_csv_fname
 
 
-def dump_bill_csvs(level, abbr):
-    bill_fields = ('level', 'country', 'state', 'session', 'chamber',
+def dump_bill_csvs(abbr):
+    bill_fields = (settings.LEVEL_FIELD, 'session', 'chamber',
                    'bill_id', 'title', 'created_at', 'updated_at', 'type',
                    'subjects')
     bill_csv_fname, bill_csv = _make_csv(abbr, 'bills.csv', bill_fields)
 
-    action_fields = ('level', 'country', 'state', 'session', 'chamber',
+    action_fields = (settings.LEVEL_FIELD, 'session', 'chamber',
                      'bill_id', 'date', 'action', 'actor', 'type')
     action_csv_fname, action_csv = _make_csv(abbr, 'bill_actions.csv',
                                              action_fields)
 
-    sponsor_fields = ('level', 'country', 'state', 'session', 'chamber',
+    sponsor_fields = (settings.LEVEL_FIELD, 'session', 'chamber',
                       'bill_id', 'type', 'name', 'leg_id')
     sponsor_csv_fname, sponsor_csv = _make_csv(abbr, 'bill_sponsors.csv',
                                                sponsor_fields)
 
-    vote_fields = ('level', 'country', 'state', 'session', 'chamber',
+    vote_fields = (settings.LEVEL_FIELD, 'session', 'chamber',
                    'bill_id', 'vote_id', 'vote_chamber', 'motion', 'date',
                    'type', 'yes_count', 'no_count', 'other_count')
     vote_csv_fname, vote_csv = _make_csv(abbr, 'bill_votes.csv', vote_fields)
@@ -138,12 +138,11 @@ def dump_bill_csvs(level, abbr):
                                                'bill_legislator_votes.csv',
                                                legvote_fields)
 
-    for bill in db.bills.find({'level': level, level: abbr}):
+    for bill in db.bills.find({settings.LEVEL_FIELD: abbr}):
         bill_csv.writerow(extract_fields(bill, bill_fields))
 
         bill_info = extract_fields(bill,
-                                   ('bill_id', 'level', 'country', 'state',
-                                    'session', 'chamber'))
+                   ('bill_id', settings.LEVEL_FIELD, 'session', 'chamber'))
 
         # basically same behavior for actions, sponsors and votes:
         #    extract fields, update with bill_info, write to csv
@@ -195,11 +194,9 @@ class DumpCSV(BaseCommand):
                 upload(abbr, args.file, 'csv')
 
     def dump(self, abbr, filename):
-        level = metadata(abbr)['level']
-
         files = []
-        files += dump_legislator_csvs(level, abbr)
-        files += dump_bill_csvs(level, abbr)
+        files += dump_legislator_csvs(abbr)
+        files += dump_bill_csvs(abbr)
 
         zfile = zipfile.ZipFile(filename, 'w', zipfile.ZIP_DEFLATED)
         for fname in files:
@@ -237,7 +234,6 @@ class DumpJSON(BaseCommand):
     def dump(self, abbr, filename, validate, schema_dir):
         scraper = scrapelib.Scraper(requests_per_minute=600,
                                     follow_robots=False)
-        level = metadata(abbr)['level']
 
         zip = zipfile.ZipFile(filename, 'w', zipfile.ZIP_DEFLATED)
 
@@ -255,8 +251,7 @@ class DumpJSON(BaseCommand):
             committee_schema = json.load(f)
 
         logging.info('exporting %s bills...' % abbr)
-        for bill in db.bills.find({'level': level, level: abbr},
-                                  timeout=False):
+        for bill in db.bills.find({settings.LEVEL_FIELD: abbr}, timeout=False):
             path = "bills/%s/%s/%s/%s" % (abbr, bill['session'],
                                           bill['chamber'], bill['bill_id'])
             url = api_url(path)
@@ -269,7 +264,7 @@ class DumpJSON(BaseCommand):
             zip.writestr(path, response)
 
         logging.info('exporting %s legislators...' % abbr)
-        for legislator in db.legislators.find({'level': level, level: abbr}):
+        for legislator in db.legislators.find({settings.LEVEL_FIELD: abbr}):
             path = 'legislators/%s' % legislator['_id']
             url = api_url(path)
 
@@ -281,7 +276,7 @@ class DumpJSON(BaseCommand):
             zip.writestr(path, response)
 
         logging.info('exporting %s committees...' % abbr)
-        for committee in db.committees.find({'level': level, level: abbr}):
+        for committee in db.committees.find({settings.LEVEL_FIELD: abbr}):
             path = 'committees/%s' % committee['_id']
             url = api_url(path)
 
