@@ -16,6 +16,10 @@ BILLY_DATA_DIR = os.path.join(os.getcwd(), 'data')
 BILLY_CACHE_DIR = os.path.join(os.getcwd(), 'cache')
 BILLY_MANUAL_DATA_DIR = os.path.join(os.getcwd(), 'manual_data')
 
+BILL_FILTERS = {}
+LEGISLATOR_FILTERS = {}
+EVENT_FILTERS = {}
+
 BILLY_SUBJECTS = [
     'Agriculture and Food',
     'Animal Rights and Wildlife Issues',
@@ -65,10 +69,7 @@ BILLY_SUBJECTS = [
 
 ENABLE_OYSTER = False
 
-BILLY_LEVEL_FIELDS = {
-    'country': ('country',),
-    'state': ('state', 'country'),
-}
+LEVEL_FIELD = 'state'
 
 SCRAPELIB_RPM = 60
 SCRAPELIB_TIMEOUT = 60
