@@ -2,14 +2,17 @@ import os
 import glob
 import json
 import logging
+import datetime
 from time import time
 from collections import defaultdict
 
-from billy.conf import settings
-from billy.utils import metadata, term_for_session
-from billy.scrape import JSONDateEncoder
 from billy import db
+from billy.conf import settings
+from billy.scrape import JSONDateEncoder
+from billy.utils import metadata, term_for_session
 from billy.importers.names import get_legislator_id
+from billy.importers.filters import apply_filters
+
 from billy.importers.subjects import SubjectCategorizer
 from billy.importers.utils import (insert_with_id, update, prepare_obj,
                                    next_big_id, oysterize, fix_bill_id,
@@ -24,14 +27,15 @@ if hasattr(settings, "ENABLE_GIT") and settings.ENABLE_GIT:
 
 import pymongo
 
+filters = settings.BILL_FILTERS
 logger = logging.getLogger('billy')
 
 
 def ensure_indexes():
     # TODO: add a _current_term, _current_session index?
 
-    # accomodates basic lookup / unique constraint on state/session/bill_id
-    db.bills.ensure_index([('state', pymongo.ASCENDING),
+    # accomodates basic lookup / unique constraint on abbr/session/bill_id
+    db.bills.ensure_index([(settings.LEVEL_FIELD, pymongo.ASCENDING),
                            ('session', pymongo.ASCENDING),
                            ('chamber', pymongo.ASCENDING),
                            ('bill_id', pymongo.ASCENDING)],
@@ -47,27 +51,30 @@ def ensure_indexes():
                            ('versions.doc_id', pymongo.ASCENDING)])
 
     # common search indices
-    db.bills.ensure_index([('state', pymongo.ASCENDING),
+    db.bills.ensure_index([(settings.LEVEL_FIELD, pymongo.ASCENDING),
                            ('subjects', pymongo.ASCENDING),
                            ('action_dates.last', pymongo.DESCENDING)])
-    db.bills.ensure_index([('state', pymongo.ASCENDING),
+    db.bills.ensure_index([(settings.LEVEL_FIELD, pymongo.ASCENDING),
                            ('sponsors.leg_id', pymongo.ASCENDING),
                            ('action_dates.last', pymongo.DESCENDING)])
 
     # generic sort-assist indices on the action_dates
-    db.bills.ensure_index([('state', pymongo.ASCENDING),
+    db.bills.ensure_index([(settings.LEVEL_FIELD, pymongo.ASCENDING),
                            ('action_dates.first', pymongo.DESCENDING)])
-    db.bills.ensure_index([('state', pymongo.ASCENDING),
+    db.bills.ensure_index([(settings.LEVEL_FIELD, pymongo.ASCENDING),
                            ('action_dates.last', pymongo.DESCENDING)])
-    db.bills.ensure_index([('state', pymongo.ASCENDING),
+    db.bills.ensure_index([(settings.LEVEL_FIELD, pymongo.ASCENDING),
                            ('action_dates.passed_upper', pymongo.DESCENDING)])
-    db.bills.ensure_index([('state', pymongo.ASCENDING),
+    db.bills.ensure_index([(settings.LEVEL_FIELD, pymongo.ASCENDING),
                            ('action_dates.passed_lower', pymongo.DESCENDING)])
 
     # votes index
     db.votes.ensure_index([('_voters', pymongo.ASCENDING),
                            ('date', pymongo.ASCENDING)])
 
+    # subjects index
+    db.subjects.ensure_index('abbr')
+
 
 def import_votes(data_dir):
     pattern = os.path.join(data_dir, 'votes', '*.json')
@@ -137,7 +144,7 @@ def git_commit(message):
     c.tree = git_active_tree.id
     c.parents = [HEAD]
     repo.object_store.add_object(git_active_tree)
-    c.author = c.committer = "Billy <openstates@sunlightfoundation.com>"
+    c.author = c.committer = "Billy <billy@localhost>"
     c.commit_time = c.author_time = int(time())
     tz = parse_timezone("-0400")[0]
     c.commit_timezone = c.author_timezone = tz
@@ -163,7 +170,7 @@ Fondly,
     tree.add("README", 0100644, blob.id)
     commit = Commit()
     commit.tree = tree.id
-    author = "Billy <openstates@sunlightfoundation.com>"
+    author = "Billy <billy@localhost>"
     commit.author = commit.committer = author
     commit.commit_time = commit.author_time = int(time())
     tz = parse_timezone('-0400')[0]
@@ -203,7 +210,7 @@ def git_prelod(abbr):
 def oysterize_version(bill, version):
     titles = [bill['title']] + bill.get('alternate_titles', [])
     logger.info('{0} tracked in oyster'.format(version['doc_id']))
-    oysterize(version['url'], bill['state'] + ':billtext',
+    oysterize(version['url'], bill[settings.LEVEL_FIELD] + ':billtext',
               id=version['doc_id'],
               # metadata
               mimetype=version.get('mimetype', None),
@@ -216,8 +223,7 @@ def oysterize_version(bill, version):
 
 
 def import_bill(data, votes, categorizer):
-    level = data['level']
-    abbr = data[level]
+    abbr = data[settings.LEVEL_FIELD]
 
     # clean up bill_ids
     data['bill_id'] = fix_bill_id(data['bill_id'])
@@ -237,10 +243,10 @@ def import_bill(data, votes, categorizer):
     if categorizer:
         categorizer.categorize_bill(data)
 
-    # this is a hack added for Rhode Island where we can't
+    # this is a hack initially added for Rhode Island where we can't
     # determine the full bill_id, if this key is in the metadata
     # we just use the numeric portion, not ideal as it won't work
-    # in states where HB/SBs overlap, but in RI they never do
+    # where HB/SBs overlap, but in RI they never do
     if metadata(abbr).get('_partial_vote_bill_id'):
         # pull off numeric portion of bill_id
         numeric_bill_id = data['bill_id'].split()[1]
@@ -253,7 +259,22 @@ def import_bill(data, votes, categorizer):
 
     data['votes'].extend(bill_votes)
 
-    bill = db.bills.find_one({'level': level, level: abbr,
+    # companions
+    for companion in data['companions']:
+        companion['bill_id'] = fix_bill_id(companion['bill_id'])
+        # query based on companion
+        spec = companion.copy()
+        spec[settings.LEVEL_FIELD] = abbr
+        if not spec['chamber']:
+            spec.pop('chamber')
+        companion_obj = db.bills.find_one(spec)
+        if companion_obj:
+            companion['internal_id'] = companion_obj['_id']
+        else:
+            logger.warning('Unknown companion: {chamber} {session} {bill_id}'
+                           .format(**companion))
+
+    bill = db.bills.find_one({settings.LEVEL_FIELD: abbr,
                               'session': data['session'],
                               'chamber': data['chamber'],
                               'bill_id': data['bill_id']})
@@ -274,8 +295,7 @@ def import_bill(data, votes, categorizer):
                                sponsor['name'])
         sponsor['leg_id'] = id
         if id is None:
-            cid = get_committee_id(level, abbr, data['chamber'],
-                                   sponsor['name'])
+            cid = get_committee_id(abbr, data['chamber'], sponsor['name'])
             if not cid is None:
                 sponsor['committee_id'] = cid
 
@@ -284,7 +304,7 @@ def import_bill(data, votes, categorizer):
 
         # committee_ids
         if 'committee' in vote:
-            committee_id = get_committee_id(level, abbr, vote['chamber'],
+            committee_id = get_committee_id(abbr, vote['chamber'],
                                             vote['committee'])
             vote['committee_id'] = committee_id
 
@@ -301,11 +321,27 @@ def import_bill(data, votes, categorizer):
     # process actions
     dates = {'first': None, 'last': None, 'passed_upper': None,
              'passed_lower': None, 'signed': None}
+
+    vote_flags = {
+        "bill:passed",
+        "bill:failed",
+        "bill:veto_override:passed",
+        "bill:veto_override:failed",
+        "amendment:passed",
+        "amendment:failed",
+        "committee:passed",
+        "committee:passed:favorable",
+        "committee:passed:unfavorable",
+        "committee:passed:failed"
+    }
+    already_linked = set()
+    remove_vote = set()
+
     for action in data['actions']:
         adate = action['date']
 
         def _match_committee(name):
-            return get_committee_id(level, abbr, action['actor'], name)
+            return get_committee_id(abbr, action['actor'], name)
 
         def _match_legislator(name):
             return get_legislator_id(abbr,
@@ -330,13 +366,13 @@ def import_bill(data, votes, categorizer):
                 id = resolver(entity['name'])
                 entity['id'] = id
 
-        # first & last
+        # first & last dates
         if not dates['first'] or adate < dates['first']:
             dates['first'] = adate
         if not dates['last'] or adate > dates['last']:
             dates['last'] = adate
 
-        # passed & signed
+        # passed & signed dates
         if (not dates['passed_upper'] and action['actor'] == 'upper'
             and 'bill:passed' in action['type']):
             dates['passed_upper'] = adate
@@ -346,6 +382,35 @@ def import_bill(data, votes, categorizer):
         elif (not dates['signed'] and 'governor:signed' in action['type']):
             dates['signed'] = adate
 
+        # vote-action matching
+        action_attached = False
+        if set(action['type']).intersection(vote_flags):
+            for vote in data['votes']:
+                if not vote['date'] or not action['date']:
+                    continue
+
+                delta = abs(vote['date'] - action['date'])
+                if (delta < datetime.timedelta(hours=20) and
+                    vote['chamber'] == action['actor']):
+                    if action_attached:
+                        # multiple votes match, we can't guess
+                        if "related_votes" in action:
+                            del(action['related_votes'])
+                    else:
+                        related_vote = vote['vote_id']
+                        if related_vote in already_linked:
+                            remove_vote.add(related_vote)
+
+                        already_linked.add(related_vote)
+                        action['related_votes'] = [related_vote]
+                        action_attached = True
+
+    # remove related_votes that we linked to multiple actions
+    for action in data['actions']:
+        for vote in remove_vote:
+            if "related_votes" in action and vote in action['related_votes']:
+                action['related_votes'].remove(vote)
+
     # save action dates to data
     data['action_dates'] = dates
 
@@ -370,14 +435,17 @@ def import_bill(data, votes, categorizer):
     except KeyError:
         pass
     data['alternate_titles'] = list(alt_titles)
+    data = apply_filters(filters, data)
 
     if not bill:
         bill_id = insert_with_id(data)
         git_add_bill(data)
+
         denormalize_votes(data, bill_id)
         return "insert"
     else:
         git_add_bill(bill)
+
         update(bill, data, db.bills)
         denormalize_votes(bill, bill['_id'])
         return "update"
@@ -417,9 +485,7 @@ def import_bills(abbr, data_dir):
         logger.debug('Failed to match vote %s %s %s' % tuple([
             r.encode('ascii', 'replace') for r in remaining]))
 
-    meta = db.metadata.find_one({'_id': abbr})
-    level = meta['level']
-    populate_current_fields(level, abbr)
+    populate_current_fields(abbr)
 
     git_commit("Import Update")
 
@@ -428,7 +494,7 @@ def import_bills(abbr, data_dir):
     return counts
 
 
-def populate_current_fields(level, abbr):
+def populate_current_fields(abbr):
     """
     Set/update _current_term and _current_session fields on all bills
     for a given location.
@@ -437,7 +503,7 @@ def populate_current_fields(level, abbr):
     current_term = meta['terms'][-1]
     current_session = current_term['sessions'][-1]
 
-    for bill in db.bills.find({'level': level, level: abbr}):
+    for bill in db.bills.find({settings.LEVEL_FIELD: abbr}):
         if bill['session'] == current_session:
             bill['_current_session'] = True
         else:
@@ -460,7 +526,7 @@ def denormalize_votes(bill, bill_id):
         vote = vote.copy()
         vote['_id'] = vote['vote_id']
         vote['bill_id'] = bill_id
-        vote['state'] = bill['state']
+        vote[settings.LEVEL_FIELD] = bill[settings.LEVEL_FIELD]
         vote['_voters'] = [l['leg_id'] for l in vote['yes_votes']]
         vote['_voters'] += [l['leg_id'] for l in vote['no_votes']]
         vote['_voters'] += [l['leg_id'] for l in vote['other_votes']]
