@@ -1,6 +1,4 @@
 import re
-import unicodecsv
-import os.path
 import logging
 
 from billy import db
@@ -23,11 +21,9 @@ def get_legislator_id(abbr, session, chamber, name):
         else:
             raise Exception("bad session: " + session)
 
-        matcher = NameMatcher(abbr, term['name'], metadata['level'])
-        __matchers[(abbr, session)] = matcher
+        matcher = NameMatcher(abbr, term['name'])
 
-    if chamber == 'both' or chamber == 'joint' or chamber == 'other':
-        chamber = None
+        __matchers[(abbr, session)] = matcher
 
     return matcher.match(name, chamber)
 
@@ -66,18 +62,17 @@ class NameMatcher(object):
     are no longer unique and will not be matched with either legislator.
     """
 
-    def __init__(self, abbr, term, level):
+    def __init__(self, abbr, term):
         self._names = {'upper': {}, 'lower': {}, None: {}}
         self._codes = {'upper': {}, 'lower': {}, None: {}}
-        self._manual = {'upper': {}, 'lower': {}, None: {}}
+        self._manual = {'upper': {}, 'lower': {}, None: {}, 'joint': {}}
         self._abbr = abbr
         self._term = term
 
-        roles_elemMatch = {'level': level, level: abbr, 'type': 'member',
+        roles_elemMatch = {settings.LEVEL_FIELD: abbr, 'type': 'member',
                            'term': term}
         old_roles_query = {'old_roles.%s' % term: {'$elemMatch':
-                                                   {'level': level,
-                                                    level: abbr,
+                                                   {settings.LEVEL_FIELD: abbr,
                                                     'type': 'member'}}}
 
         for legislator in db.legislators.find({
@@ -92,21 +87,18 @@ class NameMatcher(object):
         self._learn_manual_matches()
 
     def _learn_manual_matches(self):
-        path = os.path.join(settings.BILLY_MANUAL_DATA_DIR,
-                            "leg_ids/%s.csv" % self._abbr)
-        try:
-            with open(path) as f:
-                reader = unicodecsv.reader(f)
+        rows = db.manual.leg_ids.find({"abbr": self._abbr})
 
-                for (term, chamber, name, leg_id) in reader:
-                    if term == self._term and leg_id:
-                        self._manual[chamber][name] = leg_id
-                        if name in self._manual[None]:
-                            self._manual[None][name] = None
-                        else:
-                            self._manual[None][name] = leg_id
-        except IOError:
-            pass
+        for row in rows:
+            (term, chamber, name, leg_id) = (
+                    row['term'], row['chamber'], row['name'], row['leg_id'])
+
+            if (term == self._term or not term) and leg_id:
+                self._manual[chamber][name] = leg_id
+                if name in self._manual[None]:
+                    self._manual[None][name] = None
+                else:
+                    self._manual[None][name] = leg_id
 
     def _normalize(self, name):
         """
@@ -218,6 +210,9 @@ class NameMatcher(object):
         except KeyError:
             pass
 
+        if chamber == 'joint':
+            chamber = None
+
         try:
             return self._codes[chamber][name]
         except KeyError:
