@@ -1,19 +1,9 @@
 from billy.conf import settings
-from billy import db
-from billy.models import base
+# modify the db name upon initial import (this file has to run first)
+settings.MONGO_DATABASE += '_test'
 import pymongo
 
 
-def setup():
-    host = settings.MONGO_HOST
-    port = settings.MONGO_PORT
-    settings.MONGO_DATABASE += '_test'
-    db_name = settings.MONGO_DATABASE
-
-    db._db = pymongo.Connection(host, port)[db_name]
-    base.db = db._db
-
-
 def teardown():
     host = settings.MONGO_HOST
     port = settings.MONGO_PORT
