@@ -11,7 +11,7 @@ def setup_func():
 
 @with_setup(setup_func)
 def test_import_event_guid():
-    event = {'level': 'state', 'state': 'ex', 'description': 'TBD',
+    event = {'state': 'ex', 'description': 'TBD',
              'when': 'now', 'end': 'never', 'type': 'party',
              '_guid': 'xx-yy-zz'}
 
@@ -32,7 +32,7 @@ def test_import_event_guid():
 
 @with_setup(setup_func)
 def test_import_event_no_guid():
-    event = {'level': 'state', 'state': 'ex', 'description': 'TBD',
+    event = {'state': 'ex', 'description': 'TBD',
              'when': 'now', 'end': 'never', 'type': 'party'}
 
     # test insert
