@@ -19,6 +19,15 @@ urlpatterns = patterns('billy.web.admin.views',
     url(r'^(?P<abbr>[a-z]{2})/subjects-remove/(?P<id>.+)/$', 'subjects_remove',
         name='admin_subjects_remove'),
 
+    # Leg ID stuff
+    url(r'^(?P<abbr>[a-z]{2})/leg_ids/$', 'leg_ids',
+        name='admin_leg_ids'),
+    url(r'^(?P<abbr>[a-z]{2})/leg_ids-commit/$', 'leg_ids_commit',
+        name='admin_leg_ids_commit'),
+    url(r'^(?P<abbr>[a-z]{2})/leg_ids-remove/(?P<id>.+)/$', 'leg_ids_remove',
+        name='admin_leg_ids_remove'),
+
+
     # admin overview pages
     url(r'^(?P<abbr>[a-z]{2})/$', 'overview', name='admin_overview'),
     url(r'^(?P<abbr>[a-z]{2})/metadata/$', 'metadata_json',
@@ -61,14 +70,8 @@ urlpatterns = patterns('billy.web.admin.views',
         name='admin_event'),
 
     # missing data
-    url(r'^(?P<abbr>[a-z]{2})/uncategorized_subjects/$',
-        'uncategorized_subjects', name='uncategorized_subjects'),
     url(r'^(?P<abbr>[a-z]{2})/other_actions/$', 'other_actions',
         name='other_actions'),
-    url(r'^(?P<abbr>[a-z]{2})/unmatched_leg_ids/$', 'unmatched_leg_ids',
-        name='unmatched_leg_ids'),
-    url(r'^(?P<abbr>[a-z]{2})/district_stub/$', 'district_stub',
-        name='district_stub'),
     url(r'^(?P<abbr>[a-z]{2})/duplicate_versions/$', 'duplicate_versions',
         name='duplicate_versions'),
 
