@@ -23,6 +23,7 @@ from django.shortcuts import render, redirect
 from django.http import Http404, HttpResponse
 from django.template.loader import render_to_string
 from django.views.decorators.cache import never_cache
+from django.contrib.auth.decorators import login_required
 from django.views.decorators.http import require_http_methods
 
 from billy import db
@@ -51,6 +52,7 @@ def keyfunc(obj):
         return obj['district']
 
 
+@login_required
 def _csv_response(request, csv_name, columns, data, abbr):
     if 'csv' in request.REQUEST:
         resp = HttpResponse(mimetype="text/plain")
@@ -66,6 +68,7 @@ def _csv_response(request, csv_name, columns, data, abbr):
                        'data': data, 'metadata': metadata(abbr)})
 
 
+@login_required
 def browse_index(request, template='billy/index.html'):
     rows = []
 
@@ -79,6 +82,8 @@ def browse_index(request, template='billy/index.html'):
         meta = db.metadata.find_one({'_id': report['_id']})
         report['name'] = meta['name']
         report['unicameral'] = ('lower_chamber_name' not in meta)
+        report['influence_explorer'] = ('influenceexplorer' in
+                                        meta['feature_flags'])
         report['bills']['typed_actions'] = (100 -
             report['bills']['actions_per_type'].get('other', 100))
         rows.append(report)
@@ -88,6 +93,7 @@ def browse_index(request, template='billy/index.html'):
     return render(request, template, {'rows': rows})
 
 
+@login_required
 def overview(request, abbr):
     meta, report = _meta_and_report(abbr)
     context = {}
@@ -95,28 +101,31 @@ def overview(request, abbr):
     context['report'] = report
     context['sessions'] = db.bills.find({'state': abbr}).distinct('session')
 
+    def _add_time_delta(runlog):
+        time_delta = runlog['scraped']['ended'] - runlog['scraped']['started']
+        runlog['scraped']['time_delta'] = datetime.timedelta(time_delta.days,
+                                                         time_delta.seconds)
     try:
         runlog = db.billy_runs.find({
             "scraped.state": abbr
         }).sort("scraped.started", direction=pymongo.DESCENDING)[0]
-        # This hack brought to you by Django's inability to do subtraction
-        # in the template:)
-        runlog['scraped']['time_delta'] = (runlog['scraped']['ended'] -
-                                           runlog['scraped']['started'])
+        _add_time_delta(runlog)
         context['runlog'] = runlog
-        if "failure" in runlog:
-            context['alert'] = dict(type='error',
-                                    title="This build is currently broken!",
-                                    message="""
-The last scrape was a failure. Check in the run log section for more details,
-or check out the scrape run report page for this state.
-""")
+
+        if runlog.get('failure'):
+            last_success = db.billy_runs.find({
+                "scraped.state": abbr,
+                "failure": None,
+            }).sort("scraped.started", direction=pymongo.DESCENDING)[0]
+            _add_time_delta(last_success)
+            context['last_success'] = last_success
     except IndexError:
         runlog = False
 
     return render(request, 'billy/state_index.html', context)
 
 
+@login_required
 def metadata_json(request, abbr):
     re_attr = re.compile(r'^    "(.{1,100})":', re.M)
     obj = metadata(abbr)
@@ -138,6 +147,7 @@ def metadata_json(request, abbr):
     return render(request, 'billy/metadata_json.html', context)
 
 
+@login_required
 def run_detail_graph_data(request, abbr):
 
     def rolling_average(oldAverage, newItem, oldAverageCount):
@@ -264,6 +274,7 @@ def run_detail_graph_data(request, abbr):
         content_type="text/plain")
 
 
+@login_required
 def run_detail(request, obj=None):
     try:
         run = db.billy_runs.find({
@@ -279,6 +290,7 @@ def run_detail(request, obj=None):
     })
 
 
+@login_required
 def state_run_detail(request, abbr):
     try:
         allruns = db.billy_runs.find({
@@ -313,6 +325,7 @@ for the exception and error message.
 
 
 @never_cache
+@login_required
 def bills(request, abbr):
     meta, report = _meta_and_report(abbr)
 
@@ -470,6 +483,7 @@ def bills(request, abbr):
                        tablespecs=tablespecs))
 
 
+@login_required
 def summary_index(request, abbr, session):
 
     object_types = 'votes actions versions sponsors documents sources'.split()
@@ -496,6 +510,7 @@ def summary_index(request, abbr, session):
     return render(request, 'billy/summary_index.html', {'summary': summary})
 
 
+@login_required
 def summary_object_key(request, abbr, urlencode=urllib.urlencode,
                        collections=("bills", "legislators", "committees"),
                        dumps=json.dumps, Decimal=decimal.Decimal):
@@ -539,6 +554,7 @@ def summary_object_key(request, abbr, urlencode=urllib.urlencode,
     return render(request, 'billy/summary_object_key.html', locals())
 
 
+@login_required
 def summary_object_key_vals(request, abbr, urlencode=urllib.urlencode,
                         collections=("bills", "legislators", "committees")):
     meta = metadata(abbr)
@@ -574,6 +590,7 @@ def summary_object_key_vals(request, abbr, urlencode=urllib.urlencode,
         ))
 
 
+@login_required
 def object_json(request, collection, _id,
                 re_attr=re.compile(r'^    "(.{1,100})":', re.M)):
 
@@ -618,6 +635,7 @@ def object_json(request, collection, _id,
         obj=obj, obj_id=obj_id, obj_json=obj_json, obj_url=obj_url))
 
 
+@login_required
 def other_actions(request, abbr):
     report = db.reports.find_one({'_id': abbr})
     if not report:
@@ -626,54 +644,7 @@ def other_actions(request, abbr):
                          sorted(report['bills']['other_actions']), abbr)
 
 
-def unmatched_leg_ids(request, abbr):
-    report = db.reports.find_one({'_id': abbr})
-    if not report:
-        raise Http404('No reports found for abbreviation %r.' % abbr)
-    bill_unmatched = set(tuple(i) for i in
-                         report['bills']['unmatched_leg_ids'])
-    com_unmatched = set(tuple(i) for i in
-                         report['committees']['unmatched_leg_ids'])
-    combined_sets = bill_unmatched | com_unmatched
-    return _csv_response(request, 'leg_ids', ('term', 'chamber', 'name'),
-                         sorted(combined_sets), abbr)
-
-
-def uncategorized_subjects(request, abbr):
-    report = db.reports.find_one({'_id': abbr})
-    if not report:
-        raise Http404('No reports found for abbreviation %r.' % abbr)
-    subjects = sorted(report['bills']['uncategorized_subjects'],
-                      key=lambda t: (t[1], t[0]), reverse=True)
-    return _csv_response(request, 'uncategorized_subjects', ('subject', '#'),
-                         subjects, abbr)
-
-
-def district_stub(request, abbr):
-    def keyfunc(x):
-        try:
-            district = int(x[2])
-        except ValueError:
-            district = x[2]
-        return x[1], district
-
-    counts = defaultdict(int)
-    for leg in db.legislators.find({'state': abbr, 'active': True}):
-        if 'chamber' in leg:
-            counts[(leg['chamber'], leg['district'])] += 1
-
-    data = []
-    for key, count in counts.iteritems():
-        chamber, district = key
-        data.append((abbr, chamber, district, count, ''))
-
-    data.sort(key=keyfunc)
-
-    return _csv_response(request, "districts",
-                         ('abbr', 'chamber', 'district', 'count', ''),
-                         data, abbr)
-
-
+@login_required
 def duplicate_versions(request, abbr):
     meta, report = _meta_and_report(abbr)
 
@@ -683,11 +654,10 @@ def duplicate_versions(request, abbr):
 
 def _bill_spec(meta, limit):
     abbr = meta['abbreviation']
-    level = meta['level']
 
     # basic spec
     latest_session = meta['terms'][-1]['sessions'][-1]
-    spec = {'level': level, level: abbr.lower(), 'session': latest_session}
+    spec = {settings.LEVEL_FIELD: abbr.lower(), 'session': latest_session}
 
     basic_specs = {
         "no_versions": {'versions': []},
@@ -710,6 +680,7 @@ def _bill_spec(meta, limit):
 
 
 @never_cache
+@login_required
 def random_bill(request, abbr):
     meta = metadata(abbr)
     if not meta:
@@ -738,6 +709,7 @@ def random_bill(request, abbr):
     return render(request, 'billy/bill.html', context)
 
 
+@login_required
 def bill_list(request, abbr):
     meta = metadata(abbr)
     if not meta:
@@ -765,6 +737,7 @@ def bill_list(request, abbr):
     return render(request, 'billy/bill_list.html', context)
 
 
+@login_required
 def bad_vote_list(request, abbr):
     meta = metadata(abbr)
     if not meta:
@@ -778,15 +751,15 @@ def bad_vote_list(request, abbr):
     return render(request, 'billy/vote_list.html', context)
 
 
+@login_required
 def bill(request, abbr, session=None, id=None, billy_id=None):
     meta = metadata(abbr)
 
     if billy_id:
         bill = db.bills.find_one({'_id': billy_id})
     else:
-        level = meta['level']
-        bill = find_bill({'level': level, level: abbr,
-                          'session': session, 'bill_id': id.upper()})
+        bill = find_bill({settings.LEVEL_FIELD: abbr, 'session': session,
+                         'bill_id': id.upper()})
     if not bill:
         msg = 'No bill found in {name} session {session!r} with id {id!r}.'
         raise Http404(msg.format(name=meta['name'], session=session, id=id))
@@ -795,17 +768,17 @@ def bill(request, abbr, session=None, id=None, billy_id=None):
                   {'bill': bill, 'metadata': meta, 'id': bill['_id']})
 
 
+@login_required
 def legislators(request, abbr):
     meta = metadata(abbr)
-    level = metadata(abbr)['level']
 
     report = db.reports.find_one({'_id': abbr})['legislators']
 
-    upper_legs = db.legislators.find({'level': level, level: abbr.lower(),
+    upper_legs = db.legislators.find({settings.LEVEL_FIELD: abbr.lower(),
                                       'active': True, 'chamber': 'upper'})
-    lower_legs = db.legislators.find({'level': level, level: abbr.lower(),
+    lower_legs = db.legislators.find({settings.LEVEL_FIELD: abbr.lower(),
                                       'active': True, 'chamber': 'lower'})
-    inactive_legs = db.legislators.find({'level': level, level: abbr.lower(),
+    inactive_legs = db.legislators.find({settings.LEVEL_FIELD: abbr.lower(),
                                          'active': False})
     upper_legs = sorted(upper_legs, key=keyfunc)
     lower_legs = sorted(lower_legs, key=keyfunc)
@@ -821,6 +794,89 @@ def legislators(request, abbr):
     })
 
 
+@login_required
+def leg_ids(request, abbr):
+    meta = metadata(abbr)
+    report = db.reports.find_one({'_id': abbr})
+    legs = list(db.legislators.find({"state": abbr}))
+
+    leg_ids = db.manual.leg_ids.find({"abbr": abbr})
+    sorted_ids = {}
+    known_legs = {}
+    for leg in legs:
+        known_legs[leg['leg_id']] = leg
+
+    def _id(term, chamber, name):
+        return "%s-%s-%s" % (term, chamber, name)
+
+    for item in leg_ids:
+        key = _id(item['term'], item['chamber'], item['name'])
+        sorted_ids[key] = item
+
+    if not report:
+        raise Http404('No reports found for abbreviation %r.' % abbr)
+    bill_unmatched = set(tuple(i) for i in
+                         report['bills']['unmatched_leg_ids'])
+    com_unmatched = set(tuple(i) for i in
+                         report['committees']['unmatched_leg_ids'])
+    combined_sets = bill_unmatched | com_unmatched
+    eyedees = []
+
+    for term, chamber, name in combined_sets:
+        key = _id(term, chamber, name)
+        if key in sorted_ids:
+            continue
+
+        eyedees.append((term, chamber, name))
+
+    return render(request, 'billy/leg_ids.html', {
+        "metadata": meta,
+        "leg_ids": eyedees,
+        "all_ids": sorted_ids,
+        "known_legs": known_legs,
+        "legs": legs
+    })
+
+
+@login_required
+def leg_ids_remove(request, abbr=None, id=None):
+    db.manual.leg_ids.remove({"_id": id}, safe=True)
+    return redirect('admin_leg_ids', abbr)
+
+
+@login_required
+@require_http_methods(["POST"])
+def leg_ids_commit(request, abbr):
+    ids = dict(request.POST)
+    for eyedee in ids:
+        term, chamber, name = eyedee.split(",", 2)
+        value = ids[eyedee][0]
+        if value == "Unknown":
+            continue
+
+        thing = "%s-%s-%s-%s" % (
+            value,
+            name,
+            chamber,
+            term
+        )
+
+        db.manual.leg_ids.update({"_id": thing},
+                         {
+                             "_id": thing,
+                             "name": name,
+                             "term": term,
+                             "abbr": abbr,
+                             "leg_id": value,
+                             "chamber": chamber,
+                         },
+                         True,  # Upsert
+                         safe=True)
+
+    return redirect('admin_leg_ids', abbr)
+
+
+@login_required
 def subjects(request, abbr):
     meta = metadata(abbr)
 
@@ -838,7 +894,7 @@ def subjects(request, abbr):
 
     subjects.rewind()
 
-    uniqid = 0
+    uniqid = 1
 
     for sub in uc_s:
         if not sub[0] in c_subjects:
@@ -846,24 +902,27 @@ def subjects(request, abbr):
             uniqid += 1
             uc_subjects.append(sub)
 
+    normalized_subjects = settings.BILLY_SUBJECTS[:]
+    normalized_subjects.append("IGNORED")
+
     return render(request, 'billy/subjects.html', {
         'metadata': meta,
         'subjects': subjects,
-        'normalized_subjects': settings.BILLY_SUBJECTS,
+        'normalized_subjects': normalized_subjects,
         'uncat_subjects': uc_subjects
     })
 
 
+@login_required
 def subjects_remove(request, abbr=None, id=None):
-    meta = metadata(abbr)
-    obj = db.subjects.remove({"_id": id})
-
+    db.subjects.remove({"_id": id}, safe=True)
     return redirect('admin_subjects', abbr)
 
 
+@login_required
 @require_http_methods(["POST"])
 def subjects_commit(request, abbr):
-    meta = metadata(abbr)
+
     def _gen_id(abbr, subject):
         return "%s-%s" % (abbr, subject)
 
@@ -882,12 +941,15 @@ def subjects_commit(request, abbr):
     for idex in catd_subjects:
         sub = catd_subjects[idex]
 
-        remote = sub['remote'][0].strip()
+        remote = sub['remote'][0]
         normal = [x.strip() for x in sub['normal']]
 
         if normal == []:
             continue
 
+        if "IGNORED" in normal:
+            normal = []
+
         eyedee = _gen_id(abbr, remote)
 
         obj = {
@@ -896,7 +958,6 @@ def subjects_commit(request, abbr):
             "remote": remote,
             "normal": normal
         }
-#        print obj
 
         db.subjects.update({"_id": eyedee},
                            obj,
@@ -906,6 +967,7 @@ def subjects_commit(request, abbr):
     return redirect('admin_subjects', abbr)
 
 
+@login_required
 def quality_exceptions(request, abbr):
     meta = metadata(abbr)
 
@@ -922,6 +984,7 @@ def quality_exceptions(request, abbr):
     })
 
 
+@login_required
 def quality_exception_remove(request, abbr, obj):
     meta = metadata(abbr)
     errors = []
@@ -937,6 +1000,7 @@ def quality_exception_remove(request, abbr, obj):
     return redirect('quality_exceptions', abbr)
 
 
+@login_required
 def quality_exception_commit(request, abbr):
     def classify_object(oid):
         oid = oid.upper()
@@ -1002,14 +1066,12 @@ def quality_exception_commit(request, abbr):
     return redirect('quality_exceptions', abbr)
 
 
+@login_required
 def events(request, abbr):
     meta = metadata(abbr)
-    level = metadata(abbr)['level']
 
-    events = db.events.find({
-        'level': level,
-        level: abbr.lower()
-    }, sort=[('when', pymongo.DESCENDING)]).limit(20)
+    events = db.events.find({settings.LEVEL_FIELD: abbr.lower()},
+                            sort=[('when', pymongo.DESCENDING)]).limit(20)
 
     # sort and get rid of old events.
 
@@ -1019,6 +1081,7 @@ def events(request, abbr):
     })
 
 
+@login_required
 def event(request, abbr, event_id):
     meta = metadata(abbr)
     event = db.events.find_one(event_id)
@@ -1028,23 +1091,25 @@ def event(request, abbr, event_id):
     })
 
 
+@login_required
 def legislator(request, id):
     leg = db.legislators.find_one({'_all_ids': id})
     if not leg:
         raise Http404('No legislators found for id %r.' % id)
 
-    meta = metadata(leg[leg['level']])
+    meta = metadata(leg[settings.LEVEL_FIELD])
 
     return render(request, 'billy/legislator.html', {'leg': leg,
                                                      'metadata': meta})
 
 
+@login_required
 def legislator_edit(request, id):
     leg = db.legislators.find_one({'_all_ids': id})
     if not leg:
         raise Http404('No legislators found for id %r.' % id)
 
-    meta = metadata(leg[leg['level']])
+    meta = metadata(leg[settings.LEVEL_FIELD])
     return render(request, 'billy/legislator_edit.html', {
         'leg': leg,
         'metadata': meta,
@@ -1064,16 +1129,30 @@ def legislator_edit(request, id):
     })
 
 
+@login_required
 @require_http_methods(["POST"])
 def legislator_edit_commit(request):
     payload = dict(request.POST)
 
+    sources = payload.pop('change_source')
     leg_id = payload['leg_id'][0]
 
     legislator = db.legislators.find_one({'_all_ids': leg_id})
     if not legislator:
         raise Http404('No legislators found for id %r.' % leg_id)
 
+    cur_sources = [x['url'] for x in legislator['sources']]
+
+    for source in sources:
+        if source and source.strip() != "":
+            source = source.strip()
+            if source in cur_sources:
+                continue
+
+            legislator['sources'].append({
+                "url": source
+            })
+
     del(payload['leg_id'])
 
     update = {}
@@ -1096,14 +1175,14 @@ def legislator_edit_commit(request):
     return redirect('admin_legislator_edit', legislator['leg_id'])
 
 
+@login_required
 def retire_legislator(request, id):
     legislator = db.legislators.find_one({'_all_ids': id})
     if not legislator:
         raise Http404('No legislators found for id %r.' % id)
 
     # retire a legislator
-    level = legislator['level']
-    abbr = legislator[level]
+    abbr = legislator[settings.LEVEL_FIELD]
     meta = metadata(abbr)
 
     term = meta['terms'][-1]['name']
@@ -1118,7 +1197,7 @@ def retire_legislator(request, id):
     else:
         cur_role['end_date'] = datetime.datetime.strptime(end_date, '%Y-%m-%d')
         db.legislators.save(legislator, safe=True)
-        deactivate_legislators(term, abbr, level)
+        deactivate_legislators(term, abbr)
         alert = dict(type='success', title='Retired Legislator',
                      message='{0} was successfully retired.'.format(
                          legislator['full_name']))
@@ -1129,15 +1208,15 @@ def retire_legislator(request, id):
                                                     })
 
 
+@login_required
 def committees(request, abbr):
     meta = metadata(abbr)
-    level = metadata(abbr)['level']
 
-    upper_coms = db.committees.find({'level': level, level: abbr.lower(),
+    upper_coms = db.committees.find({settings.LEVEL_FIELD: abbr.lower(),
                                      'chamber': 'upper'})
-    lower_coms = db.committees.find({'level': level, level: abbr.lower(),
+    lower_coms = db.committees.find({settings.LEVEL_FIELD: abbr.lower(),
                                       'chamber': 'lower'})
-    joint_coms = db.committees.find({'level': level, level: abbr.lower(),
+    joint_coms = db.committees.find({settings.LEVEL_FIELD: abbr.lower(),
                                       'chamber': 'joint'})
     upper_coms = sorted(upper_coms)
     lower_coms = sorted(lower_coms)
@@ -1151,10 +1230,11 @@ def committees(request, abbr):
     })
 
 
+@login_required
 def delete_committees(request):
     ids = request.POST.getlist('committees')
     committees = db.committees.find({'_id': {'$in': ids}})
-    abbr = committees[0][committees[0]['level']]
+    abbr = committees[0][settings.LEVEL_FIELD]
     if not request.POST.get('confirm'):
         return render(request, 'billy/delete_committees.html',
                       {'abbr': abbr, 'committees': committees})
@@ -1163,6 +1243,7 @@ def delete_committees(request):
         return redirect('admin_committees', abbr)
 
 
+@login_required
 def mom_index(request, abbr):
     legislators = list(db.legislators.find({"state": abbr}))
     return render(request, 'billy/mom_index.html', {
@@ -1171,6 +1252,7 @@ def mom_index(request, abbr):
     })
 
 
+@login_required
 def mom_commit(request, abbr):
     actions = []
 
@@ -1238,6 +1320,7 @@ def _mom_mangle(attr):
     return attr
 
 
+@login_required
 def mom_merge(request, abbr):
     leg1 = "leg1"
     leg2 = "leg2"
@@ -1277,6 +1360,7 @@ def mom_merge(request, abbr):
         'remove': toRemove, 'merge_view_info': mv_info, "abbr": abbr})
 
 
+@login_required
 def newsblogs(request):
     '''
     Demo view for news/blog aggregation.
